WebDAV access
=============

AlekSIS allows users to access calendar and person data via CalDAV and CardDAV. 
This enables you to view this information in a local
client of your choice with offline support. This includes calendars, as seen on your own calendar
overview page, and all persons you are allowed to view. Persons are made accessible as
contacts bundled in one address book, while each calendar corresponds to a calendar feed.
All information is provided read-only. Syncing local changes back to AlekSIS is thus not
possible.

You can configure CalDAV and CardDAV access in any client that supports auto discovery,
such as Thunderbird. In order to gain access, use the domain of your
AlekSIS instance as location and authenticate yourself with your AlekSIS credentials.
